%!TeX root = authors-kit.tex
%
% overlay.cls - Version 2020.2
%
% Copyright 2019-2020 Nicola Gigante
%
% Redistribution and use, with or without modification, are permitted provided
% that the following conditions are met:
%
% 1. Redistributions must retain the above copyright notice, this list of
%    conditions and the following disclaimer.
%
% 2. Neither the name of the copyright holder nor the names of its contributors
%    may be used to endorse or promote products derived from this software
%    without specific prior written permission.
%

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{overlay}[2019/06/22 OVERLAY workshop LaTeX class file]

% Basic TeX trickery used below
\RequirePackage{etoolbox} % For \appto and easy booleans
\RequirePackage{xparse}

\newbool{proceedings}
\newbool{ceur}

% Paper authors do not need to be concerned with these options
\DeclareOption{proceedings}{
  \booltrue{proceedings}
}

\DeclareOption{ceur}{
  \booltrue{ceur}
}

\ProcessOptions\relax

%
% We are very simply based on the `article' standard class for papers,
% and the `book' standard class for the final proceedings volume
%
\ifbool{proceedings}{
  \LoadClass[10pt,twoside]{book}
}{
  \LoadClass[10pt,twoside]{article}
}

%
% Page layout
%
\RequirePackage[a4paper]{geometry}

\geometry{
  hmargin=2.5cm,
  height=22.8cm,
  vcentering,
  headsep=25pt
}

%
% Typography
%
\RequirePackage[T1]{fontenc}
\RequirePackage{lmodern}
\RequirePackage[final]{microtype}

\raggedbottom

%
% Running heads
%
\RequirePackage[pagestyles]{titlesec}
\RequirePackage{titletoc}

\def\theworkshoptitle{}
\ifbool{ceur}{
  \newcommand\theworkshoptitle{
    Proceedings of the\\
    2nd Workshop on Artificial Intelligence and Formal Verification, Logics, 
    Automata and Synthesis (\textsf{OVERLAY}),\\
    Bozen-Bolzano, Italy, September 25--26, 2020
  }
}{}

\newcommand\workshoptitle[1]{%
  \renewcommand\theworkshoptitle{#1}%
}

\newcommand\insertworkshoptitle{%
  \parbox{\textwidth}{\centering\footnotesize\theworkshoptitle}%
}

\newcommand\therunningauthors{\thecopyrightauthors}
\newcommand\therunningtitle{%
  \begingroup
  \def\thanks##1{}%
  \ov@title
  \endgroup
}

\newcommand\runningauthors[1]{%
  \renewcommand\therunningauthors{#1}%
}

\newcommand\runningtitle[1]{%
  \renewcommand\therunningtitle{#1}%
}

% Pagestyle used in papers
\newpagestyle{main}{
  \sethead[\thepage][][\therunningauthors] % even pages, authors on the right
          {\therunningtitle}{}{\thepage}   % odd pages, title on the left
}

\newpagestyle{papertitle}{
  \sethead{}{\insertworkshoptitle}{} % Proceedings title on first page
}

\ifbool{proceedings}{
  \pagestyle{empty}%
  \appto\frontmatter{\pagestyle{empty}}%
  \assignpagestyle{\chapter}{empty}%
  \patchcmd{\part}{plain}{empty}{}{}% \assignpagestyle does not work for parts
}{
  \pagestyle{main}
}

% Code stops here for the proceedings volume, all the rest is for single papers
\ifbool{proceedings}{\endinput}{}

%
% Title and authors block
%
\RequirePackage{titling}
\RequirePackage[noblocks]{authblk}

\pretitle{\begin{center}\bfseries\LARGE}
\posttitle{\end{center}\vspace{0.5em}}

\setlength\affilsep{2ex}
\newcommand\email[2][ ]{%
  \affil[#1]{{\normalsize\texttt{#2}}}%
}

% We print no date
\date{}
\renewcommand\date[1]{}
\predate{}
\postdate{}

%
% Copyright note
%
\RequirePackage{array,multirow}
\RequirePackage{graphicx}

\newcommand\thecopyrightauthors{%
  \ClassError{overlay}{%
    Please specify the authors copyright note with
    \string\copyrightauthors{...}%
  }
}
\newcommand\copyrightauthors[1]{%
  \renewcommand\thecopyrightauthors{#1}%
}

\newbool{ccbyfootnote}
\booltrue{ccbyfootnote}

\NewDocumentCommand\ccbyfootnote{}{%
  \begingroup
  \let\thefootnote\relax
  \footnotetext{%
    \parbox{\textwidth}{%
      \vspace{1ex}%
      \begin{tabular}{@{} c @{\hspace*{1em}} l}
      \multirow{2}{*}{%
        \raisebox{-2pt}{\includegraphics[height=4.5ex]{cc-by.pdf}}%
      } &
          Copyright \copyright\ \the\year\ for this paper by its authors.\\
        & Use permitted under Creative Commons License Attribution 4.0
          International (CC BY 4.0).
      \end{tabular}
    }%
  }%
  \endgroup
}

\appto\maketitle{%
  \thispagestyle{papertitle}%
  \ifbool{ccbyfootnote}{\ccbyfootnote}{}%
}

%
% Abstract
%
\RequirePackage{abstract}
\setlength\absleftindent{5em}
\setlength\absrightindent{5em}
\setlength\abstitleskip{0pt}
\renewcommand\abstractnamefont{\normalfont\bfseries}
\renewcommand\abstracttextfont{\normalfont}

%
% Customization of optional packages
%
\PassOptionsToPackage{capitalise,nameinlink,noabbrev}{cleveref}

%
% Output of metadata for proceedings assembly
%
% appending authors to a temporary variable
% \thetitle and \theauthor are not usable for various reasons
\let\ov@oldauthor\author
\def\ov@author{}
\def\ov@title{}

\RenewDocumentCommand\author{m}{
  \appto\ov@author{, #1}
  \ov@oldauthor{#1}
}

\apptocmd\title{\def\ov@title{#1}}{}{}

\NewDocumentCommand\tocauthors{m}{%
  \def\ov@strippedauthors{#1}%
}

% Strip first comma from author list
\def\ov@strip@, #1\@endtok{#1}
\def\ov@strippedauthors{%
  \expandafter\ov@strip@\ov@author\@endtok
}

% actual output

\AfterPreamble{
  \RequirePackage{hyperref}
}

\newwrite\infofile

\NewDocumentCommand\ov@metadata{}{%
  %
  % We set the metadata to the PDF and to an external file
  %
  \begingroup
    \def\textit##1{##1}
    \def\textsf##1{##1}
    \def\textsc##1{##1}
    \def\sf{}
    \def\empth##1{##1}
    \def\thanks##1{}
    \def\(##1\){##1}
    \def\\{ }
    \hypersetup{
      pdftitle={\ov@title},
      pdfauthor={\ov@strippedauthors},
      pdfsubject={Proceedings of the 1st OVERLAY Workshop on fOrmal 
        VERification, Logics,
        Automata and sYnthesis, 19-20 November 2019, Rende, Italy}
    }
    %
    \ifbool{ceur}{%
      \immediate\openout\infofile=paper.info
        \immediate\write\infofile{\ov@title}
        \immediate\write\infofile{\ov@strippedauthors}
      \immediate\closeout\infofile
    }{}
  \endgroup
  %
  % We set the initial page from the paper.page file written by the
  % first compilation of the proceedings volume
  %
  \IfFileExists{paper.page}{%
    \newread\pagefile
    \openin\pagefile=paper.page
      \read\pagefile to \paperpage
    \closein\pagefile
    \setcounter{page}{\paperpage}%
  }{}%
}

\AtEndPreamble{
  \@ifpackageloaded{xcolor}{}{
    \RequirePackage{xcolor}
  }
}

\NewDocumentCommand\ov@linkcolors{}{
  \@ifpackageloaded{hyperref}{
    \definecolor{overlay-blue}{HTML}{004E98}
    \definecolor{overlay-orange}{HTML}{FF6600}

    \hypersetup{
      colorlinks = true,
      linkcolor = overlay-blue,
      citecolor = overlay-blue,
      urlcolor = overlay-blue
    }
  }{}
}

% Some tasks to perform at the beginning of the document
\AtBeginDocument{%
  \ov@metadata
  \ov@linkcolors
}
